<?php

/**
 * @file
 * Contains \Drupal\scroll_top_button\Form\ScrollTopButtonSettingsForm.
 */

namespace Drupal\scroll_top_button\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ScrollTopButtonSettingsForm.
 *
 * Admin config form definition for the scroll to top button options.
 *
 * @package Drupal\scroll_top_button\Form
 */
class ScrollTopButtonSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'scroll_top_button.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'scroll_top_button_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('scroll_top_button.settings');

    $form['general_seettings'] = [
      '#type'  => 'details',
      '#title' => $this->t('General settings'),
      '#open' => TRUE,
    ];

    $form['general_seettings']['stb_enabled'] = [
      '#type' => 'radios',
      '#title' => $this->t('Enable scroll to top button'),
      '#default_value' => $config->get('stb_enabled') ? $config->get('stb_enabled') : 'off',
      '#options' => ['on' => $this->t('Enable'), 'off' => $this->t('Disable')],
      '#required' => TRUE,
    ];

    $form['general_seettings']['stb_show_on_admin'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show scroll to top button on admin pages'),
      '#default_value' => $config->get('stb_show_on_admin'),
    ];

    $form['button_options'] = [
      '#type'  => 'details',
      '#title' => $this->t('Manage scroll to top button options'),
      '#open' => TRUE,
    ];

    $form['button_options']['stb_button_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button text'),
      '#default_value' => $config->get('stb_button_text'),
      '#required' => TRUE,
      '#description' => $this->t('Text to show on the scroll to top button'),
    ];

    $form['button_options']['stb_button_style'] = [
      '#type' => 'select',
      '#title' => $this->t('Button style to display'),
      '#default_value' => $config->get('stb_button_style'),
      '#options' => [
        'image' => $this->t('Image'),
        'link' => $this->t('Link'),
        'pill' => $this->t('Pill'),
        'tab' => $this->t('Tab')
      ],
      '#required' => TRUE,
    ];

    $form['button_options']['stb_button_animation'] = [
      '#type' => 'select',
      '#title' => $this->t('Button animation effect'),
      '#default_value' => $config->get('stb_button_animation'),
      '#options' => [
        'fade' => $this->t('Fade'),
        'slide' => $this->t('Slide'),
        'none' => $this->t('None')
      ],
      '#required' => TRUE,
      '#description' => $this->t('Choose a animation effect when button will display'),
    ];

    $form['button_options']['stb_button_animation_speed'] = [
      '#title' => $this->t('Button animation speed (ms)'),
      '#description' => $this->t('Enter the value of button animation speed'),
      '#type' => 'number',
      '#required' => TRUE,
      '#default_value' => $config->get('stb_button_animation_speed'),
    ];

    $form['scroll_options'] = [
      '#type'  => 'details',
      '#title' => $this->t('Manage page scrolling options'),
      '#open' => TRUE,
    ];

    $form['scroll_options']['stb_scroll_distance'] = [
      '#title' => $this->t('Scroll distance (px)'),
      '#description' => $this->t('Distance from top before showing button'),
      '#type' => 'number',
      '#required' => TRUE,
      '#default_value' => $config->get('stb_scroll_distance'),
    ];

    $form['scroll_options']['stb_scroll_speed'] = [
      '#title' => $this->t('Speed scroll to top (ms)'),
      '#type' => 'number',
      '#required' => TRUE,
      '#default_value' => $config->get('stb_scroll_speed'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->configFactory->getEditable(static::SETTINGS)
      // Set the submitted configuration setting.
      ->set('stb_enabled', $form_state->getValue('stb_enabled'))
      ->set('stb_show_on_admin', $form_state->getValue('stb_show_on_admin'))
      ->set('stb_button_text', $form_state->getValue('stb_button_text'))
      ->set('stb_button_style', $form_state->getValue('stb_button_style'))
      ->set('stb_button_animation', $form_state->getValue('stb_button_animation'))
      ->set('stb_button_animation_speed', $form_state->getValue('stb_button_animation_speed'))
      ->set('stb_scroll_distance', $form_state->getValue('stb_scroll_distance'))
      ->set('stb_scroll_speed', $form_state->getValue('stb_scroll_speed'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
